@@ -1,4 +1,4 @@
 #!/bin/sh
 # Run this to generate all the initial makefiles, etc.
 
-lrelease src/src.pro
+lrelease kylin-assistant.pro
