@@ -72,7 +72,7 @@ MainWindow::MainWindow(QString cur_arch, int d_count, QWidget* parent/*, Qt::Win
 //    this->setWindowFlags(/*Qt::Window | */Qt::FramelessWindowHint | Qt::WindowMinimizeButtonHint);//Attention: Qt::WindowCloseButtonHint make showMinimized() valid
 
     //this->setWindowFlags(Qt::FramelessWindowHint | Qt::WindowCloseButtonHint | Qt::WindowMinimizeButtonHint);
-    this->setWindowFlags(Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint);
+    this->setWindowFlags(Qt::FramelessWindowHint);
     //For UKUI and Mate
 //    this->setWindowFlags(Qt::FramelessWindowHint  | Qt::WindowCloseButtonHint);
     this->setAttribute(Qt::WA_TranslucentBackground);
@@ -215,7 +215,7 @@ void MainWindow::initWidgets()
     connect(setting_action_widget, SIGNAL(closeApp()), this, SLOT(closeYoukerAssistant()));
     setting_action_widget->setPalette(palette_back);
     setting_action_widget->setImage("://res/systemset.png");
-    setting_action_widget->setTipMessage(tr("You can perform a full range of customized systems based on personal preferences"));
+    setting_action_widget->setTipMessage(tr("perform a full range of customizations systems based on your own personal preferences"));
     m_topStack->addWidget(setting_action_widget);
 
     box_action_widget = new TopBaseWidget(this);
@@ -224,7 +224,7 @@ void MainWindow::initWidgets()
     connect(box_action_widget, SIGNAL(closeApp()), this, SLOT(closeYoukerAssistant()));
     box_action_widget->setPalette(palette_back);
     box_action_widget->setImage("://res/toolkits.png");
-    box_action_widget->setTipMessage(tr("Provide a practical and lightweight tool, create fast and convenient experience for you"));
+    box_action_widget->setTipMessage(tr("Provides lightweight tool and creates fast and convenient experience"));
     m_topStack->addWidget(box_action_widget);
 
     //middle
@@ -937,14 +937,14 @@ void MainWindow::setCurrentPageIndex(int index)
         m_bottomStack->setFixedSize(info_widget->size());
         status = INFOPAGE;
     }
-    else if (index == 3 && status != SETTINGPAGE) {
-        m_topStack->setCurrentWidget(setting_action_widget);
-        m_bottomStack->setCurrentWidget(setting_widget);
-        m_topStack->setFixedSize(setting_action_widget->size());
-        m_bottomStack->setFixedSize(setting_widget->size());
-        status = SETTINGPAGE;
-    }
-    else if (index == 4 && status != BOXPAGE) {
+//    else if (index == 3 && status != SETTINGPAGE) {
+//        m_topStack->setCurrentWidget(setting_action_widget);
+//        m_bottomStack->setCurrentWidget(setting_widget);
+//        m_topStack->setFixedSize(setting_action_widget->size());
+//        m_bottomStack->setFixedSize(setting_widget->size());
+//        status = SETTINGPAGE;
+//    }
+    else if (index == 3 && status != BOXPAGE) {
         m_topStack->setCurrentWidget(box_action_widget);
         m_bottomStack->setCurrentWidget(box_widget);
         m_topStack->setFixedSize(box_action_widget->size());
